summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mislead.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/mislead.h')
-rw-r--r--crawl-ref/source/mislead.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/crawl-ref/source/mislead.h b/crawl-ref/source/mislead.h
index 540ffea9b1..cc5d2ebed3 100644
--- a/crawl-ref/source/mislead.h
+++ b/crawl-ref/source/mislead.h
@@ -1,8 +1,10 @@
/* File: mislead.h
* Summary: Handling of the Mislead spell and stats
*/
bool unsuitable_misled_monster(monster_type mons);
monster_type get_misled_monster (monsters *monster);
int update_mislead_monsters(monsters* caster);
bool update_mislead_monster(monsters* monster);
+int count_mara_fakes();
+
@@ -1,8 +1,10 @@
/* File: mislead.h
- * Summary: Handling of the Mislead spell and stats
+ * Summary: Handling of Mara's Mislead spell and stats, plus fakes.
*/
bool unsuitable_misled_monster(monster_type mons);